@@ -110,12 +110,6 @@ _domCanInsert( xmlNodePtr cur, xmlNodePtr ref );
 DLLEXPORT int
 domTestDocument( xmlNodePtr cur, xmlNodePtr ref );
 
-/**
- * part A:
- *
- * class Node
- **/
-
 /* A.1 DOM specified section */
 
 DLLEXPORT xmlChar*
@@ -170,12 +164,6 @@ domNodeIsReferenced(xmlNodePtr self);
 DLLEXPORT void
 domReleaseNode( xmlNodePtr node );
 
-/**
- * part B:
- *
- * class Document
- **/
-
 /**
  * NAME domImportNode
  * TYPE function
@@ -197,11 +185,8 @@ domReleaseNode( xmlNodePtr node );
 DLLEXPORT xmlNodePtr
 domImportNode( xmlDocPtr document, xmlNodePtr node, int move, int reconcileNS );
 
-/**
- * part C:
- *
- * class Element
- **/
+DLLEXPORT int
+domNodeType(xmlChar* name);
 
 DLLEXPORT xmlNodeSetPtr
 domGetChildrenByLocalName( xmlNodePtr self, xmlChar* name );
